"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseModel = void 0;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const model_middleware_1 = require("./model-middleware");
class BaseModel {
    constructor(middleware, name, schemas) {
        this.schemas = schemas;
        this.middleware = middleware;
        this.model = middleware.client[name] || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_FOUND, 'Model is not found', { name });
    }
    async run(accessInfo, promise) {
        const context = {
            schemas: this.schemas,
            accessInfo
        };
        return await this.middleware.run(context, promise);
    }
    async browse(params) {
        params ??= {};
        const pagination = params.pagination || {};
        const options = params.options || {};
        delete params.pagination;
        delete params.options;
        pagination.page = !(0 < pagination.page) ? 1 : pagination.page;
        pagination.pageSize ??= 10;
        params.where ??= {
            status: model_middleware_1.RecordStatus.ACTIVE,
            ...params.where
        };
        params.orderBy ??= { createdAt: 'desc' };
        if (0 < pagination.pageSize) {
            params.take = pagination.pageSize;
            params.skip = (pagination.page - 1) * pagination.pageSize;
        }
        const promises = [this.model['findMany'](params)];
        if (!(options.speedMode ??= false)) {
            promises.push(this.model['count']({ where: params.where }));
        }
        const results = await Promise.all(promises);
        const ret = {
            items: results[0],
            properties: options.speedMode ? pagination : { ...pagination, count: results[1] }
        };
        return ret;
    }
    get client() {
        return this.middleware.client;
    }
}
exports.BaseModel = BaseModel;
//# sourceMappingURL=model.js.map